package com.ruoyi.ems.mapper;

import com.ruoyi.ems.domain.ElecValencyType;

import java.util.List;


/**
 * 电价计量分类Mapper接口
 * 
 * @author ruoyi
 * @date 2024-07-29
 */
public interface ElecValencyTypeMapper
{
    /**
     * 查询电价计量分类
     * 
     * @param id 电价计量分类主键
     * @return 电价计量分类
     */
     ElecValencyType selectElecValencyTypeById(Long id);

    /**
     * 查询电价计量分类列表
     * 
     * @param elecValencyType 电价计量分类
     * @return 电价计量分类集合
     */
     List<ElecValencyType> selectElecValencyTypeList(ElecValencyType elecValencyType);

    /**
     * 新增电价计量分类
     * 
     * @param elecValencyType 电价计量分类
     * @return 结果
     */
     int insertElecValencyType(ElecValencyType elecValencyType);

    /**
     * 修改电价计量分类
     * 
     * @param elecValencyType 电价计量分类
     * @return 结果
     */
     int updateElecValencyType(ElecValencyType elecValencyType);

    /**
     * 删除电价计量分类
     * 
     * @param id 电价计量分类主键
     * @return 结果
     */
     int deleteElecValencyTypeById(Long id);

    /**
     * 批量删除电价计量分类
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
     int deleteElecValencyTypeByIds(Long[] ids);
}
